/*
 * Copyright (c) 1997 David J. Wilson.
 * All rights reserved.
 *
 * Copyright (c) 1997 Philip R. Wilson.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of any co-contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include <ctype.h>
#include <stdio.h>
#include <string.h>
#include "ansi_io.h"

#ifndef lint
static const char rcsid[] = "$Id: ansi_io.c,v 1.2 1997/06/09 06:47:24 prw Exp $";
#endif /* not lint */


int colour(int colour_change)
{
        int ansi, entog = false;

        if (colour_change > 7)
                entog = true;

        switch (colour_change) {
                case 8:
                case 0:
                        ansi = 30;
                        break;
                case 9:
                case 1:
                        ansi = 34;
                        break;
                case 10:
                case 2:
                        ansi = 32;
                        break;
                case 11:
                case 3:
                        ansi = 36;
                        break;
                case 12:
                case 4:
                        ansi = 31;
                        break;
                case 13:
                case 5:
                        ansi = 35;
                        break;
                case 14:
                case 6:
                        ansi = 33;
                        break;
                case 15:
                case 7:
                        ansi = 37;
                        break;

                default:
                        if (DEBUG)
                                fprintf(stderr, 
                                "libansi_io: colour(): invalid value\n");
                        return (0);
        }
        printf("\033[%d;%dm", entog, ansi);
        return (1);
}


int aio_read(char *string, int length)
{
        int counter = 0;
        int i;
	int saveval = timeout_val;

	if (length < 1)
		return (0);

        strncpy(string, "\0", length);
        getch_timeout(-1); 

        while (1) {
                fflush(stdout);
                i = getch();
                if (((i == '\010') || (i == '\177')) && (counter > 0)) {
                        putchar('\b');
                        putchar(' ');
                        putchar('\b');
                        counter--;
                        string[counter] = '\0';
                }
                if ((i == '\n') || (i == '\015')) {
                        putchar('\n');
                        break;
                }
                if (counter < (length)) {
                        if ((i != '\010') && (i != '\177')) {
                                string[counter] = i;
                                if ((string[counter] != '\n') && (string[counter] != '\015'))                                       putchar(string[counter]);
                                counter++;
                        }
                }
        }
        string[counter] = '\0';
        getch_timeout(saveval);

	return (1);
} 


void aio_write(char *write)
{
#ifdef PIPECODES
        char temp[4];
        int temp2;
#endif
        int i;

        for (i = 0; i < (strlen(write)); i++) {

#ifdef PIPECODES
                if (write[i] == '|') {
                        temp[0] = write[i+1];
                        temp[1] = write[i+2];
                        sscanf(temp, "%d", &temp2);
                        if ( ((temp2 >= 0) && (temp2 <= 15)) && ((isdigit(temp[0]) != 0) && (isdigit(temp[1]) != 0))) {                                colour(temp2);
                                i += 3;
                        }
                        else {
                                printf("%c", write[i]);
                                continue;
                        }
                }
#endif
                if (write[i] == '\0')
                        break;

#ifdef PIPECODES
                if ((write[i] != '|') && (write[i] != '~'))
#endif 
                        printf("%c", write[i]);
#ifdef PIPECODES
                if (write[i] == '|')
                        i--;
#endif
        }
}


void gotoxy(int x, int y)
{
        printf("\033[%d;%dH", x, y);
}

